@@ -1,10 +1,8 @@
 confint.mcmc.list.dc <-
 function(object, parm, level = 0.95, ...)
 {
-    ## retrieve posterior means
-    cf <- coef(object)
     ## handling names and subsetting according to parm
-    pnames <- names(cf)
+    pnames <- varnames(object)
     if (missing(parm)) 
         parm <- pnames
     else if (is.numeric(parm)) 
@@ -12,12 +10,15 @@ function(object, parm, level = 0.95, ...)
     ## confidence levels based on level arg
     a <- (1 - level)/2
     a <- c(a, 1 - a)
-    ## Normal quantiles
-    fac <- qnorm(a)
     ## scientific formatting
+    np <- length(parm)
     pct <- paste(format(100 * a, trim = TRUE, scientific = FALSE, digits = 3), "%")
     ## empty array to fill up with values
-    ci <- array(NA, dim = c(length(parm), 2L), dimnames = list(parm, pct))
+    ci <- array(NA, dim = c(np, 2L), dimnames = list(parm, pct))
+    ## retrieve posterior means
+    cf <- coef(object)
+    ## Normal quantiles
+    fac <- qnorm(a)
     ## DC SD calculation
     ses <- dcsd(object)[parm]
     ## calculates actual CIs
