@@ -5,8 +5,10 @@ function(x, ...)
     y <- mcmcapply(x, array)
     Mean <- apply(y, 2, mean)
     Sd <- apply(y, 2, sd)
-    rhat <- if (nchain(x) > 1)
-        gelman.diag(x)$psrf[,1] else NA
+    if (nchain(x) > 1) {
+        abin <- getOption("dclone.autoburnin")
+        rhat <- gelman.diag(x, autoburnin=abin)$psrf[,1]
+    } else rhat <- NA
     if (!is.null(quantiles)) {
         Qa <- apply(y, 2, quantile, probs=quantiles)
         rval <- rbind(mean = Mean, sd = Sd, Qa, r.hat=rhat)
