@@ -1,5 +1,6 @@
 plot.dctable <-
-function(x, which = 1:length(x), type=c("all", "var", "logvar"), position = "topright", box.cex = 0.75, ...)
+function(x, which = 1:length(x), type=c("all", "var", "log.var"),
+position = "topright", box.cex = 0.75, box.bg = NA, ...)
 {
     plotit <- function(param, show.legend, ...) {
         y <- x[[param]]
@@ -10,21 +11,20 @@ function(x, which = 1:length(x), type=c("all", "var", "logvar"), position = "top
         }
         if (type=="all") {
             ylim <- range(y[,"2.5%"], y[,"97.5%"], y$mean - y$sd, y$mean + y$sd)
-            plot(xval, y$mean, ylim=ylim, xlim=xlim, pch=pch, type = "b", lty=2,
+            plot(xval, y$mean, ylim=ylim, xlim=xlim, pch=pch, type = "n", lty=2,
                 xlab = "Number of clones", ylab="Estimate",
                 main = param, axes = FALSE, ...)
+            points(xval, y$mean, pch=pch, type = "b", lty=2)
         } else {
-            FUN <- switch(type,
-                "var" = function(x) return(x),
-                "logvar" = function(x) log(x))
             ylim <- switch(type,
                 "var" = range(0, 1, y$sd^2/y$sd[1]^2),
-                "logvar" = range(0, log(y$sd^2/y$sd[1]^2)))
+                "log.var" = range(0, log(y$sd^2/y$sd[1]^2)))
             ylab <- switch(type,
-                "var" = "Scaled Variance",
-                "logvar" = "log(Scaled Variance)")
+                "var" = "Scaled variance",
+                "log.var" = "log(Scaled variance)")
+            xlab <- "Number of clones"
             plot(xval, FUN(y$sd^2/y$sd[1]^2), ylim=ylim, xlim=xlim, pch=pch, type = "b", lty=1,
-                xlab = "Number of clones", ylab=ylab,
+                xlab = xlab, ylab=ylab,
                 main = param, axes = FALSE, ...)
         }
         axis(1, xval, k)
@@ -36,6 +36,8 @@ function(x, which = 1:length(x), type=c("all", "var", "logvar"), position = "top
                 paste("R.hat < ", round(crit, 1), sep="")))
         }
         if (type=="all") {
+            if (!is.na(box.bg))
+                errlines(xval, cbind(y[,"25%"], y[,"75%"]), width=w, code=3, type="b", bg=box.bg)
             errlines(xval, cbind(y$mean - y$sd, y$mean + y$sd))
             errlines(xval, cbind(y[,"25%"], y[,"50%"]), width=w, code=3, type="b")
             errlines(xval, cbind(y[,"50%"], y[,"75%"]), width=w, code=3, type="b")
@@ -45,13 +47,23 @@ function(x, which = 1:length(x), type=c("all", "var", "logvar"), position = "top
             lines(xval, FUN(kmin/k), lty=2)
         }
     }
+    if (max(which) > length(x))
+        stop("'which' too large")
     type <- match.arg(type)
+    crit <- getOption("dclone.rhat")
+    nam <- names(x)[which]
+    w <- box.cex
     k <- x[[1]]$n.clones
     kmin <- min(k)
     xval <- 1:length(k)
-    crit <- getOption("dclone.crit")["rhat"]
-    nam <- names(x)[which]
-    w <- box.cex
+    FUN <- function(x) return(x)
+    if (type == "log.var") {
+#        k <- log(k)
+#        kmin <- log(kmin)
+        xval <- log(k)
+        w <- 0
+        FUN <- function(x) log(x)
+    }
     m <- length(which)
     if (m <= 3) {
         nr <- 1
